pygeai.tests.snippets.embeddings package
========================================

Submodules
----------

pygeai.tests.snippets.embeddings.cache\_example module
------------------------------------------------------

.. automodule:: pygeai.tests.snippets.embeddings.cache_example
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.embeddings.cohere\_example module
-------------------------------------------------------

.. automodule:: pygeai.tests.snippets.embeddings.cohere_example
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.embeddings.generate\_embeddings module
------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.embeddings.generate_embeddings
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.embeddings.openai\_base64\_example module
---------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.embeddings.openai_base64_example
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.embeddings.openai\_example module
-------------------------------------------------------

.. automodule:: pygeai.tests.snippets.embeddings.openai_example
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.embeddings.similarity\_example module
-----------------------------------------------------------

.. automodule:: pygeai.tests.snippets.embeddings.similarity_example
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: pygeai.tests.snippets.embeddings
   :members:
   :show-inheritance:
   :undoc-members:
